@@ -148,6 +148,8 @@ extern struct t_config_option *config_look_item_buffer_filter;
 extern struct t_config_option *config_look_jump_current_to_previous_buffer;
 extern struct t_config_option *config_look_jump_previous_buffer_when_closing;
 extern struct t_config_option *config_look_jump_smart_back_to_buffer;
+extern struct t_config_option *config_look_nick_prefix;
+extern struct t_config_option *config_look_nick_suffix;
 extern struct t_config_option *config_look_mouse;
 extern struct t_config_option *config_look_mouse_timer_delay;
 extern struct t_config_option *config_look_paste_bracketed;
@@ -158,9 +160,11 @@ extern struct t_config_option *config_look_prefix_align;
 extern struct t_config_option *config_look_prefix_align_max;
 extern struct t_config_option *config_look_prefix_align_min;
 extern struct t_config_option *config_look_prefix_align_more;
+extern struct t_config_option *config_look_prefix_align_more_after;
 extern struct t_config_option *config_look_prefix_buffer_align;
 extern struct t_config_option *config_look_prefix_buffer_align_max;
 extern struct t_config_option *config_look_prefix_buffer_align_more;
+extern struct t_config_option *config_look_prefix_buffer_align_more_after;
 extern struct t_config_option *config_look_prefix_same_nick;
 extern struct t_config_option *config_look_prefix_suffix;
 extern struct t_config_option *config_look_read_marker;
@@ -197,6 +201,8 @@ extern struct t_config_option *config_color_chat_server;
 extern struct t_config_option *config_color_chat_channel;
 extern struct t_config_option *config_color_chat_nick;
 extern struct t_config_option *config_color_chat_nick_colors;
+extern struct t_config_option *config_color_chat_nick_prefix;
+extern struct t_config_option *config_color_chat_nick_suffix;
 extern struct t_config_option *config_color_chat_nick_self;
 extern struct t_config_option *config_color_chat_nick_offline;
 extern struct t_config_option *config_color_chat_nick_offline_highlight;
@@ -260,6 +266,7 @@ extern struct t_config_option *config_plugin_extension;
 extern struct t_config_option *config_plugin_path;
 extern struct t_config_option *config_plugin_save_config_on_unload;
 
+extern int config_length_nick_prefix_suffix;
 extern int config_length_prefix_same_nick;
 extern regex_t *config_highlight_regex;
 extern char **config_highlight_tags;
