@@ -27,7 +27,7 @@
 #include <gnutls/gnutls.h>
 #endif
 
-#ifdef __CYGWIN__
+#if defined(__CYGWIN__) || defined(__APPLE__) || defined(__MACH__)
 /*
  * For the connect hook, when this is defined an array of sockets will
  * be passed from the parent process to the child process instead of using
@@ -157,8 +157,8 @@ struct t_hook_command
     char ***cplt_template_args;         /* arguments for each template      */
 
     /* concatenation of arg N for each template */
-    int cplt_template_num_args_concat; /* number of concatened arguments    */
-    char **cplt_template_args_concat;  /* concatened arguments              */
+    int cplt_template_num_args_concat; /* number of concatenated arguments  */
+    char **cplt_template_args_concat;  /* concatenated arguments            */
 };
 
 /* hook command run */
