@@ -412,7 +412,7 @@ string_match (const char *string, const char *mask, int case_sensitive)
     if ((mask[0] == '*') && (last == '*'))
     {
         /* not enough chars in string to match */
-        if (len_string < len_mask - 1)
+        if (len_string < len_mask - 2)
             return 0;
         /* keep only relevant chars in mask for searching string */
         mask2 = string_strndup (mask + 1, len_mask - 2);
@@ -730,7 +730,7 @@ string_mask_to_regex (const char *mask)
     char *result;
     const char *ptr_mask;
     int index_result;
-    char *regex_special_char = ".[]{}()?+";
+    char *regex_special_char = ".[]{}()?+|^$\\";
 
     if (!mask)
         return NULL;
@@ -1491,7 +1491,7 @@ string_split_command (const char *command, char separator)
             buffer[str_idx] = '\0';
             str_idx = -1;
             p = buffer;
-            /* strip white spaces a the begining of the line */
+            /* strip white spaces a the beginning of the line */
             while (*p == ' ') p++;
             if (p  && p[0])
                 array[arr_idx++] = strdup (p);
